
Уважаемый/ая *{{ data.name | safe }}*,

Спасибо, что связались с нами. {{ created | safe }} вы отправили следующее сообщение:

**{{ data.message | safe }}**

Один из наших консультантов свяжется с вами как можно скорее.

С уважением,

*Команда*
